"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CrdSchemaToJsonSchemaConverter = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
class CrdSchemaToJsonSchemaConverter {
    constructor(logger) {
        this._logger = logger.sublogger('CrdSchemaToJsonSchemaConverter');
    }
    convert(crdSchema) {
        const schema = this._convert(crdSchema);
        if (!schema.properties) {
            schema.properties = {};
        }
        schema.properties["apiVersion"] = {
            "type": "string"
        };
        schema.properties["kind"] = {
            "type": "string"
        };
        schema.properties["metadata"] = {
            "allOf": [{
                    "$ref": "#/definitions/io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta"
                }],
            "default": {}
        };
        return schema;
    }
    _convert(crdSchema) {
        const customFix = this._applyCustomFix(crdSchema);
        if (customFix) {
            return customFix;
        }
        const schema = {
            type: crdSchema.type,
            format: crdSchema.format
        };
        if (crdSchema.properties) {
            schema.properties = this._convertProperties(crdSchema.properties);
        }
        if (crdSchema.items) {
            schema.items = this._convert(crdSchema.items);
        }
        if (crdSchema.allOf) {
            schema.allOf = this._convertArray(crdSchema.allOf);
        }
        if (the_lodash_1.default.isNotNullOrUndefined(crdSchema.default)) {
            schema.default = crdSchema.default;
        }
        if (the_lodash_1.default.isNotNullOrUndefined(crdSchema.required)) {
            schema.required = crdSchema.required;
        }
        if (the_lodash_1.default.isNotNullOrUndefined(crdSchema.enum)) {
            schema.enum = crdSchema.enum;
        }
        if (crdSchema.type === "object") {
            schema.additionalProperties = false;
            if (the_lodash_1.default.isNotNullOrUndefined(crdSchema.additionalProperties)) {
                if (the_lodash_1.default.isBoolean(crdSchema.additionalProperties)) {
                    schema.additionalProperties = crdSchema.additionalProperties;
                }
                else {
                    schema.additionalProperties = this._convert(crdSchema.additionalProperties);
                }
            }
            else {
                if (crdSchema['x-kubernetes-preserve-unknown-fields']) {
                    schema.additionalProperties = true;
                }
                else {
                    if (the_lodash_1.default.isNotNullOrUndefined(crdSchema.additionalProperties)) {
                        if (crdSchema.additionalProperties['x-kubernetes-preserve-unknown-fields']) {
                            // NOTE: Not the right way, but used in Traefik:
                            // https://raw.githubusercontent.com/traefik/traefik/v2.9/docs/content/reference/dynamic-configuration/kubernetes-crd-definition-v1.yml
                            schema.additionalProperties = true;
                        }
                    }
                }
            }
        }
        return schema;
    }
    _convertProperties(properties) {
        const converted = {};
        for (const name of the_lodash_1.default.keys(properties)) {
            converted[name] = this._convert(properties[name]);
        }
        return converted;
    }
    _convertArray(openApiSchemas) {
        return openApiSchemas.map(x => this._convert(x));
    }
    _applyCustomFix(openApiSchema) {
        if (openApiSchema.format === 'int-or-string') {
            return {
                oneOf: [
                    { type: "string" },
                    { type: "integer" }
                ]
            };
        }
        return null;
    }
}
exports.CrdSchemaToJsonSchemaConverter = CrdSchemaToJsonSchemaConverter;
//# sourceMappingURL=crd-schema-to-json-schema-converter.js.map