"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.K8sApiSchemaRegistry = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
const glob_1 = __importDefault(require("glob"));
const fs = __importStar(require("fs"));
const Path = __importStar(require("path"));
const semver_1 = __importDefault(require("semver"));
const path_resolver_1 = require("../path-resolver");
class K8sApiSchemaRegistry {
    constructor(logger) {
        this._versions = {};
        this._logger = logger.sublogger('K8sApiSchemaRegistry');
    }
    init() {
        const pathResolver = new path_resolver_1.PathResolver();
        const files = glob_1.default.sync(`${pathResolver.k8sApiSchemaDir}/*.json`);
        // this._logger.info("Files: ", files);
        for (const file of files) {
            const name = Path.basename(file, '.json');
            const versionInfo = {
                path: file,
                semver: semver_1.default.parse(name)
            };
            this._versions[versionInfo.semver.version] = versionInfo;
        }
        // this._logger.info("VERSIONS: ", this._versions)
    }
    getVersions() {
        return the_lodash_1.default.keys(this._versions);
    }
    getVersionSchema(version) {
        const versionInfo = this._versions[version];
        try {
            const contents = fs.readFileSync(versionInfo.path, 'utf8');
            return JSON.parse(contents);
        }
        catch (reason) {
            throw new Error(`Failed to load JSON schema from ${versionInfo.path}`);
        }
    }
    findLatestVersion() {
        var _a;
        const candidates = the_lodash_1.default.values(this._versions).map(x => x.semver);
        const versionInfo = (_a = the_lodash_1.default.head(candidates.sort(semver_1.default.rcompare))) !== null && _a !== void 0 ? _a : null;
        if (versionInfo) {
            return versionInfo.version;
        }
        return null;
    }
    findVersion(targetVersion) {
        var _a;
        let partsStr = targetVersion.split('.');
        partsStr = partsStr.map(x => x.replace(/\D/g, ''));
        const versionParts = partsStr.map(x => parseInt(x));
        // this._logger.info("    target: ", versionParts);
        const result = {
            found: false,
            foundExact: true,
            result: null,
            candidates: []
        };
        let candidates = the_lodash_1.default.values(this._versions).map(x => x.semver);
        if (versionParts.length > 0) {
            let nextCandidates = candidates.filter(x => x.major === versionParts[0]);
            if (nextCandidates.length > 0) {
                candidates = nextCandidates;
                if (versionParts.length > 1) {
                    nextCandidates = candidates.filter(x => x.minor === versionParts[1]);
                    if (nextCandidates.length > 0) {
                        candidates = nextCandidates;
                        if (versionParts.length > 2) {
                            nextCandidates = candidates.filter(x => x.patch === versionParts[2]);
                            if (nextCandidates.length > 0) {
                                candidates = nextCandidates;
                            }
                            else {
                                result.foundExact = false;
                            }
                        }
                    }
                    else {
                        result.foundExact = false;
                    }
                }
            }
            else {
                result.foundExact = false;
            }
        }
        result.candidates = candidates.map(x => x.version);
        const selectedVersion = (_a = the_lodash_1.default.head(candidates.sort(semver_1.default.rcompare))) !== null && _a !== void 0 ? _a : null;
        result.result = selectedVersion ? selectedVersion.version : null;
        result.found = result.result ? true : false;
        if (!result.found) {
            result.foundExact = false;
        }
        return result;
    }
}
exports.K8sApiSchemaRegistry = K8sApiSchemaRegistry;
//# sourceMappingURL=k8s-api-schema-registry.js.map