"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.massageGuardOptions = exports.command = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
const logger_1 = require("../../logger");
const local_registry_populator_1 = require("../../registry/local-registry-populator");
const rule_registry_1 = require("../../rules-engine/registry/rule-registry");
const rules_runtime_1 = require("../../rules-engine/execution/rules-runtime");
const command_1 = require("../lint/command");
const remote_k8s_registry_1 = require("../../registry/remote-k8s-registry");
const combined_registry_1 = require("../../registry/combined-registry");
function command(path, options) {
    return __awaiter(this, void 0, void 0, function* () {
        logger_1.logger.info("[PATH] ", path);
        // logger.info("[areNamespacesSpecified] %s", options.areNamespacesSpecified);
        // logger.info("[NAMESPACES] ", options.namespaces);
        // throw new Error("XXX");
        const lintResult = yield (0, command_1.command)(path, options);
        const manifestPackage = lintResult.manifestPackage;
        const k8sConnector = lintResult.k8sConnector;
        const registryPopulator = new local_registry_populator_1.LocalRegistryPopulator(logger_1.logger, lintResult.k8sSchemaInfo.k8sJsonSchema, manifestPackage);
        registryPopulator.process();
        const localK8sRegistry = registryPopulator.localK8sRegistry;
        // await processor.localK8sRegistry.debugOutputToDir(logger, 'local-k8s-registry');
        // await processor.localRegistryAccessor.debugOutputToDir(logger, 'local-logic-registry');
        let remoteRegistry;
        if (k8sConnector.isUsed) {
            remoteRegistry = new remote_k8s_registry_1.RemoteK8sRegistry(logger_1.logger, k8sConnector);
        }
        const ruleRegistry = new rule_registry_1.RuleRegistry(logger_1.logger);
        if (!options.skipRemoteRules) {
            if (remoteRegistry) {
                const ruleRegistryLoadOptions = {
                    skipClusterScope: options.skipClusterScope,
                    onlySelectedNamespaces: options.areNamespacesSpecified,
                    namespaces: options.areNamespacesSpecified
                        ? options.namespaces
                        : manifestPackage.namespaces,
                };
                yield ruleRegistry.loadRemotely(remoteRegistry, ruleRegistryLoadOptions);
            }
        }
        if (!options.skipLocalRules) {
            const ruleRegistryLoadOptions = {
                skipClusterScope: options.skipClusterScope,
                onlySelectedNamespaces: true,
                namespaces: options.areNamespacesSpecified
                    ? options.namespaces
                    : manifestPackage.namespaces,
            };
            yield ruleRegistry.loadLocally(localK8sRegistry, ruleRegistryLoadOptions);
        }
        let combinedRegistry = localK8sRegistry;
        if (remoteRegistry) {
            combinedRegistry = new combined_registry_1.CombinedRegistry(logger_1.logger, [localK8sRegistry, remoteRegistry]);
        }
        let targetQueryRegistry = localK8sRegistry;
        if (options.includeRemoteTargets) {
            targetQueryRegistry = combinedRegistry;
        }
        const validatorQueryRegistry = combinedRegistry;
        let executionNamespaces = [];
        if (options.areNamespacesSpecified) {
            executionNamespaces = options.namespaces;
        }
        else {
            executionNamespaces = manifestPackage.namespaces;
        }
        const rulesRuntime = new rules_runtime_1.RulesRuntime(logger_1.logger, ruleRegistry, manifestPackage, executionNamespaces, targetQueryRegistry, validatorQueryRegistry);
        yield rulesRuntime.init();
        yield rulesRuntime.execute();
        return {
            manifestPackage: manifestPackage,
            k8sSchemaInfo: lintResult.k8sSchemaInfo,
            rulesRuntime
        };
    });
}
exports.command = command;
function massageGuardOptions(options) {
    // logger.info("XXXXX: ", options.namespaces);
    // throw new Error("KUKU");
    var _a, _b, _c, _d;
    let areNamespacesSpecified = false;
    let namespaces = [];
    if (options.namespace) {
        areNamespacesSpecified = true;
        namespaces = [options.namespace];
    }
    else {
        if (!the_lodash_1.default.isUndefined(options.namespaces)) {
            if (the_lodash_1.default.isBoolean(options.namespaces)) {
                areNamespacesSpecified = true;
                namespaces = [];
            }
            else {
                areNamespacesSpecified = true;
                namespaces = options.namespaces;
            }
        }
    }
    return Object.assign(Object.assign({}, (0, command_1.massageLintOptions)(options)), { includeRemoteTargets: (_a = options.includeRemoteTargets) !== null && _a !== void 0 ? _a : false, skipLocalRules: (_b = options.skipLocalRules) !== null && _b !== void 0 ? _b : false, skipRemoteRules: (_c = options.skipRemoteRules) !== null && _c !== void 0 ? _c : false, areNamespacesSpecified: areNamespacesSpecified, namespace: undefined, namespaces: namespaces, skipClusterScope: (_d = options.skipClusterScope) !== null && _d !== void 0 ? _d : false });
}
exports.massageGuardOptions = massageGuardOptions;
//# sourceMappingURL=command.js.map