"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const command_action_1 = require("../../infra/command-action");
const command_1 = require("./command");
const format_1 = require("./format");
const output_1 = require("./output");
function default_1(program) {
    program
        .command('guard')
        .description('Lint local manifests and validate Kubernetes for cross-manifest violations and errors')
        .argument('[path...]', 'Path to file, directory, search pattern or URL')
        .option('--ignore-unknown', 'Ignore unknown resources. Use when manifests include CRDs and not using --live-k8s option.')
        .option('--skip-apply-crds', 'Skips CRD application.')
        .option('--k8s-version <version>', 'Target Kubernetes version. Do not use with --live-k8s option.')
        .option('--stream', 'Also read manifests from stream')
        .option('--live-k8s', 'Lint against live Kubernetes cluster. Allows validation of CRDs. Do not use with --k8s-version option.')
        .option('--kubeconfig <path>', 'Optionally set the path to the kubeconfig file. Use with --live-k8s option.')
        .option('--include-remote-targets', 'Include remote Kubernetes manifests in target rules. Use with --live-k8s option.')
        .option('--skip-local-rules', 'Skip validation of rules passed to the CLI.')
        .option('--skip-remote-rules', 'Skip validation of rules that are already in the K8s cluster. Only used wth --live-k8s flag.')
        .option('--namespace <namespace>', 'Optionally specify namespace to process.')
        .option('--namespaces [namespace...]', 'Or specify multiple namespaces to process.')
        .option('--skip-cluster-scope', 'Skip processing clustered manifests and rules.')
        .option('--json', 'Output lint result in JSON.')
        .action(new command_action_1.CommandBuilder()
        .perform((path, options) => __awaiter(this, void 0, void 0, function* () {
        const myOptions = (0, command_1.massageGuardOptions)(options);
        return (0, command_1.command)(path, myOptions);
    }))
        .format(({ manifestPackage, k8sSchemaInfo, rulesRuntime }) => {
        const result = (0, format_1.formatResult)(manifestPackage, k8sSchemaInfo, rulesRuntime);
        return result;
    })
        .output(output_1.output)
        .decideSuccess(result => {
        if (!result.success) {
            return 100;
        }
        return 0;
    })
        .build());
}
exports.default = default_1;
//# sourceMappingURL=index.js.map