"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.outputGuardSummary = exports.output = void 0;
const chalk_1 = __importDefault(require("chalk"));
const node_emoji_1 = __importDefault(require("node-emoji"));
const output_1 = require("../lint/output");
const output_2 = require("../lint/output");
function output(result) {
    (0, output_1.output)(result.lintResult, {
        skipSummary: true,
    });
    (0, output_2.print)();
    if (result.rules) {
        for (const rule of result.rules) {
            if (rule.namespace) {
                (0, output_2.print)(`${node_emoji_1.default.get('scroll')} [${rule.kind}] Namespace: ${rule.namespace}, ${rule.rule}`);
            }
            else {
                (0, output_2.print)(`${node_emoji_1.default.get('scroll')} [${rule.kind}] ${rule.rule}`);
            }
            (0, output_2.print)((0, output_1.produceSourceLine)(rule.source), 3);
            if (!rule.compiled) {
                (0, output_2.print)(`${(0, output_2.severityStatusIcon)('fail')} Failed to compile`, 3);
            }
            if (rule.errors) {
                for (const error of rule.errors) {
                    (0, output_2.print)(`${node_emoji_1.default.get(':red_circle:')} ${error}`, 6);
                }
            }
            if (rule.pass && rule.compiled) {
                if (rule.passed.length > 0) {
                    (0, output_2.print)(`${(0, output_2.severityStatusIcon)('pass')} Rule passed`, 3);
                }
                else {
                    (0, output_2.print)(`${(0, output_2.severityStatusIcon)('pass')} Rule passed. No manifests found to check.`, 3);
                }
            }
            if (!rule.pass) {
                (0, output_2.print)(`${(0, output_2.severityStatusIcon)('fail')} Rule failed`, 3);
            }
            // print(`${emoji.get('page_with_curl')} Rule: ${rule.rule}`);
            if (rule.passed.length > 0) {
                (0, output_2.print)(chalk_1.default.underline('Passed:'), 3);
                for (const manifest of rule.passed) {
                    (0, output_2.outputManifest)(manifest.manifest, (0, output_2.severityStatusIcon)('pass'), 6);
                    (0, output_2.print)((0, output_1.produceSourceLine)(manifest.source), 9);
                }
            }
            if (rule.violations) {
                (0, output_2.print)(chalk_1.default.underline('Violations:'), 3);
                for (const violation of rule.violations) {
                    (0, output_2.outputManifest)(violation.manifest, (0, output_2.severityStatusIcon)('fail'), 6);
                    (0, output_2.print)((0, output_1.produceSourceLine)(violation.source), 9);
                    if (violation.errors) {
                        for (const error of violation.errors) {
                            (0, output_2.print)(`${node_emoji_1.default.get(':red_circle:')} ${error}`, 9);
                        }
                    }
                    if (violation.warnings) {
                        for (const warn of violation.warnings) {
                            (0, output_2.print)(`${(0, output_2.severityStatusIcon)('warning')} ${warn}`, 9);
                        }
                    }
                }
            }
            (0, output_2.print)();
        }
        (0, output_2.print)();
    }
    (0, output_1.outputLintSummary)(result.lintResult);
    (0, output_2.print)();
    outputGuardSummary(result);
    (0, output_2.print)();
    (0, output_1.outputLintResult)(result.lintResult);
    (0, output_2.print)();
    if (result.success) {
        (0, output_2.print)(`${node_emoji_1.default.get('white_check_mark')} Guard Succeeded.`);
    }
    else {
        (0, output_2.print)(`${node_emoji_1.default.get('x')} Guard Failed`);
    }
}
exports.output = output;
function outputGuardSummary(result) {
    (0, output_2.print)(chalk_1.default.underline('Guard Summary'));
    (0, output_2.print)(`Rules: ${result.counters.rules.total}`, 4);
    (0, output_2.print)(`${(0, output_2.severityStatusIcon)('pass')} Rules Passed: ${result.counters.rules.passed}`, 8);
    (0, output_2.print)(`${node_emoji_1.default.get(':red_circle:')} Rules Failed: ${result.counters.rules.failed}`, 8);
    (0, output_2.print)(`${(0, output_2.severityStatusIcon)('fail')} Rules With Errors: ${result.counters.rules.withErrors}`, 8);
    (0, output_2.print)(`${(0, output_2.severityStatusIcon)('warning')} Rules With Warnings: ${result.counters.rules.withWarnings}`, 8);
    (0, output_2.print)(`Manifests: ${result.counters.manifests.total}`, 4);
    (0, output_2.print)(`${node_emoji_1.default.get('page_facing_up')} Manifests Processed: ${result.counters.manifests.processed}`, 8);
    (0, output_2.print)(`${(0, output_2.severityStatusIcon)('pass')} Manifests Passed: ${result.counters.manifests.passed}`, 8);
    (0, output_2.print)(`${(0, output_2.severityStatusIcon)('fail')} Manifests with Errors: ${result.counters.manifests.withErrors}`, 8);
    (0, output_2.print)(`${(0, output_2.severityStatusIcon)('warning')} Manifests with Warnings: ${result.counters.manifests.withWarnings}`, 8);
}
exports.outputGuardSummary = outputGuardSummary;
//# sourceMappingURL=output.js.map