"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ManifestPackage = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
const k8s_manifest_1 = require("./k8s-manifest");
class ManifestPackage {
    constructor(logger) {
        this._sources = {};
        this._manifests = [];
        this._namespaces = [];
        this._logger = logger.sublogger('ManifetPackage');
    }
    get sources() {
        return the_lodash_1.default.values(this._sources);
    }
    get manifests() {
        return this._manifests;
    }
    get namespaces() {
        return this._namespaces;
    }
    getSource(kind, path) {
        const sourceId = {
            kind: kind,
            path: path
        };
        const sourceKey = the_lodash_1.default.stableStringify(sourceId);
        let source = this._sources[sourceKey];
        if (!source) {
            source = {
                source: sourceId,
                success: true,
                errors: [],
                warnings: [],
                contents: []
            };
            this._sources[sourceKey] = source;
        }
        return source;
    }
    sourceError(source, error) {
        source.errors.push(error);
        source.success = false;
    }
    sourceErrors(source, errors) {
        for (const error of errors) {
            this.sourceError(source, error);
        }
    }
    manifestError(manifest, msg) {
        manifest.errors.push(msg);
        manifest.success = false;
    }
    manifestErrors(manifest, msgs) {
        for (const msg of msgs) {
            this.manifestError(manifest, msg);
        }
    }
    manifestWarning(manifest, msg) {
        manifest.warnings.push(msg);
        // manifest.success = false;
    }
    manifestWarnings(manifest, msgs) {
        if (msgs) {
            for (const msg of msgs) {
                this.manifestWarning(manifest, msg);
            }
        }
    }
    addManifest(source, k8sObject) {
        const k8sManifest = new k8s_manifest_1.K8sManifest(k8sObject, source);
        source.contents.push(k8sManifest);
        this._manifests.push(k8sManifest);
    }
    produceNamespaces() {
        const namespaces = {};
        for (const x of this.manifests) {
            if (x.id.namespace) {
                namespaces[x.id.namespace] = true;
            }
        }
        this._namespaces = the_lodash_1.default.keys(namespaces);
    }
}
exports.ManifestPackage = ManifestPackage;
//# sourceMappingURL=manifest-package.js.map