"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DefaultNamespaceSetter = void 0;
const k8s_1 = require("../utils/k8s");
class DefaultNamespaceSetter {
    constructor(logger, k8sJsonSchema, manifestPackage) {
        this._logger = logger.sublogger('DefaultNamespaceSetter');
        this._k8sJsonSchema = k8sJsonSchema;
        this._manifestPackage = manifestPackage;
    }
    process() {
        for (const manifest of this._manifestPackage.manifests) {
            this._processManifest(manifest);
        }
    }
    _processManifest(manifest) {
        var _a;
        if (manifest.id.namespace) {
            return;
        }
        const apiResource = {
            group: (_a = manifest.id.api) !== null && _a !== void 0 ? _a : '',
            version: manifest.id.version,
            kind: manifest.id.kind
        };
        const resourceKey = (0, k8s_1.getJsonSchemaResourceKey)(apiResource);
        const resourceInfo = this._k8sJsonSchema.resources[resourceKey];
        if (!resourceInfo) {
            return;
        }
        if (resourceInfo.namespaced) {
            manifest.id.namespace = 'default';
            if (!manifest.config.metadata) {
                manifest.config.metadata = {};
            }
            manifest.config.metadata.namespace = manifest.id.namespace;
        }
    }
}
exports.DefaultNamespaceSetter = DefaultNamespaceSetter;
//# sourceMappingURL=default-namespace-setter.js.map