"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RuleCompiler = void 0;
const the_promise_1 = require("the-promise");
const processor_1 = require("../target/processor");
const processor_2 = require("../validator/processor");
class RuleCompiler {
    constructor(logger, ruleObject, targetExecutionContext, validatorExecutionContext) {
        this._isCompiled = false;
        this._hasRuntimeErrors = false;
        this._ruleErrors = [];
        this._logger = logger.sublogger('RuleCompiler');
        this._ruleObject = ruleObject;
        this._targetProcessor = new processor_1.TargetProcessor(this._ruleObject.target, targetExecutionContext);
        this._validationProcessor = new processor_2.ValidationProcessor(this._ruleObject.script, validatorExecutionContext);
    }
    get rule() {
        return this._ruleObject;
    }
    get isCompiled() {
        return this._isCompiled;
    }
    get hasRuntimeErrors() {
        return this._hasRuntimeErrors;
    }
    get ruleErrors() {
        return this._ruleErrors;
    }
    get targetProcessor() {
        return this._targetProcessor;
    }
    get validationProcessor() {
        return this._validationProcessor;
    }
    compile() {
        this._logger.info("[compile] %s", this._ruleObject.name);
        this._isCompiled = true;
        return the_promise_1.Promise.resolve()
            .then(() => {
            return this._targetProcessor.prepare().then((result) => {
                this._logger.verbose("[compile] _targetProcessor prepare: ", result);
                if (!result.success) {
                    this._isCompiled = false;
                    this.reportScriptErrors('target', result.messages);
                }
            });
        })
            .then(() => {
            return this._validationProcessor.prepare().then((result) => {
                this._logger.verbose("[compile] _validationProcessor prepare: ", result);
                // console.log("[RULE-PROCESSOR] TARGETS PREPARE RESULT: ", result)
                // this._acceptScriptErrors('target', result)
                if (!result.success) {
                    this._isCompiled = false;
                    this.reportScriptErrors('script', result.messages);
                }
            });
        });
    }
    reportScriptErrors(source, messages) {
        this._hasRuntimeErrors = true;
        for (const x of messages) {
            const line = `Error with rule ${source}. ${x}`;
            this._ruleErrors.push({
                source: source,
                msg: line
            });
            this._logger.info("[_reportRuleError] %s", line);
        }
    }
}
exports.RuleCompiler = RuleCompiler;
//# sourceMappingURL=rule-compiler.js.map