"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.K8sTarget = exports.K8sTargetBuilder = void 0;
const scope_1 = require("../scope");
class K8sTargetBuilder {
    constructor(scope, executionContext, builderContext) {
        this._data = {
            isApiVersion: true,
            nameFilters: [],
            labelFilters: [],
        };
        this._scope = scope;
        this._executionContext = executionContext;
        this._builderContext = builderContext;
        scope.registerFinalizer(this._finalize.bind(this));
    }
    ApiVersion(apiVersion) {
        this._data.isApiVersion = true;
        this._data.apiVersion = apiVersion;
        return this;
    }
    Api(apiOrNone) {
        this._data.isApiVersion = false;
        this._data.apiOrNone = apiOrNone;
        return this;
    }
    Version(version) {
        this._data.version = version;
        return this;
    }
    Kind(kind) {
        this._data.kind = kind;
        return this;
    }
    namespace(value) {
        this._data.namespace = value;
        return this;
    }
    allNamespaces() {
        this._data.isAllNamespaces = true;
        return this;
    }
    name(value) {
        this._data.nameFilters.push(value);
        return this;
    }
    label(key, value) {
        const filter = {};
        filter[key] = value;
        return this.labels(filter);
    }
    labels(value) {
        this._data.labelFilters.push(value);
        return this;
    }
    _finalize() {
        if (!this._data.kind) {
            console.log("No Kind");
            return;
        }
        const apiVersion = this._data.isApiVersion ? this._data.apiVersion :
            (this._data.apiOrNone ? `${this._data.apiOrNone}/${this._data.version}` : this._data.version);
        if (!apiVersion) {
            console.log("No ApiVersion");
            return;
        }
        const query = {
            kind: scope_1.ScopeQueryKind.K8s,
            filter: {
                isApiVersion: true,
                apiVersion: apiVersion,
                kind: this._data.kind,
                namespace: this._data.namespace,
                isAllNamespaces: this._data.isAllNamespaces,
                nameFilters: this._data.nameFilters,
                labelFilters: this._data.labelFilters,
            }
        };
        this._scope.setupQuery(query);
    }
}
exports.K8sTargetBuilder = K8sTargetBuilder;
class K8sTarget {
    constructor(scope, executionContext) {
        this._scope = scope;
        this._executionContext = executionContext;
    }
    ApiVersion(apiVersion) {
        const builder = this._makeTargetBuilder();
        builder.ApiVersion(apiVersion);
        return builder;
    }
    Api(apiOrNone) {
        const builder = this._makeTargetBuilder();
        builder.Api(apiOrNone);
        return builder;
    }
    _makeTargetBuilder() {
        return new K8sTargetBuilder(this._scope, this._executionContext, {});
    }
}
exports.K8sTarget = K8sTarget;
//# sourceMappingURL=k8s-target-builder.js.map