"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TargetProcessor = void 0;
const the_promise_1 = require("the-promise");
const compiler_1 = require("@kubevious/kubik/dist/processors/compiler");
const scope_1 = require("../scope");
const scope_builder_1 = require("./scope-builder");
const fetcher_1 = require("../query/fetcher");
class TargetProcessor {
    constructor(src, executionContext) {
        this._src = src;
        this._scope = new scope_1.Scope();
        this._errorMessages = [];
        this._executionContext = executionContext;
    }
    get scope() {
        return this._scope;
    }
    prepare() {
        this._errorMessages = [];
        const result = {
            success: false,
            messages: this._errorMessages,
        };
        return this._loadModule()
            .then((runnable) => runnable.run())
            .then(() => {
            this._scope.finalize();
        })
            .then(() => {
            this._validate();
            result.success = result.messages.length == 0;
        })
            .catch((reason) => {
            result.success = false;
            this._addError(reason.message);
        })
            .then(() => result);
    }
    execute(applicationScope, values) {
        const rootScope = {};
        rootScope['values'] = values !== null && values !== void 0 ? values : {};
        const fetcher = new fetcher_1.QueryFetcher(this._executionContext, this._scope);
        const result = fetcher.execute(applicationScope);
        return the_promise_1.Promise.resolve(result.items);
    }
    _loadModule() {
        const rootScope = {
            values: null
        };
        const rootScopeBuilder = {
            setup: (name, func) => {
                rootScope[name] = func;
            }
        };
        return the_promise_1.Promise.resolve().then(() => {
            (0, scope_builder_1.makeTargetRootScope)(rootScopeBuilder, this._executionContext, this._scope);
            const compiler = new compiler_1.Compiler(this._src, 'RULE_TARGET', rootScope);
            return compiler.compile();
        });
    }
    _validate() {
        if (!this._scope.query) {
            this._addError('No target specified.');
            return;
        }
        this._validateQueryScope(this._scope.query);
    }
    _validateQueryScope(query) {
        if (query.kind === scope_1.ScopeQueryKind.K8s) {
            this._validateK8sQuery(query);
            return;
        }
    }
    _validateK8sQuery(query) {
    }
    _addError(msg) {
        // console.log("[TARGET-PROCESSOR] ERROR: ", msg)
        this._errorMessages.push(msg);
    }
}
exports.TargetProcessor = TargetProcessor;
//# sourceMappingURL=processor.js.map