"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PackageRenderer = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
const cli_table_1 = __importDefault(require("cli-table"));
class PackageRenderer {
    constructor(logger) {
        this._logger = logger.sublogger('PackageRenderer');
    }
    renderPackageFiles(manifestPackage) {
        const rows = the_lodash_1.default.chain(manifestPackage.sources)
            .orderBy(x => x.source.path)
            .map(x => ([x.source.path, x.contents.length.toString(), x.success ? 'OK' : 'Has Errors']))
            .value();
        const table = new cli_table_1.default({
            head: ['File', 'Manifests', 'Status'],
            // colWidths: [100, 200]
            rows: rows
        });
        console.log(table.toString());
    }
    renderPackageFileErrors(manifestPackage) {
        const filesWithErrors = the_lodash_1.default.chain(manifestPackage.sources)
            .filter(x => !x.success)
            .orderBy(x => x.source.path)
            .value();
        const rows = [];
        for (const file of filesWithErrors) {
            for (const error of file.errors) {
                rows.push([file.source.path, error]);
            }
        }
        const table = new cli_table_1.default({
            head: ['File', 'Error'],
            // colWidths: [100, 200]
            rows: rows
        });
        console.log(table.toString());
    }
    renderPackageManifests(manifestPackage) {
        const rows = the_lodash_1.default.chain(manifestPackage.manifests)
            .orderBy([x => x.source.source.path, x => x.id.namespace, x => x.id.apiVersion, x => x.id.kind, x => x.id.name])
            .map(x => { var _a, _b; return ([x.source.source.path, (_a = x.id.namespace) !== null && _a !== void 0 ? _a : '', x.id.apiVersion, x.id.kind, (_b = x.id.name) !== null && _b !== void 0 ? _b : '', x.success ? 'OK' : 'Has Errors']); })
            .value();
        const table = new cli_table_1.default({
            head: ['File', 'Namespace', 'ApiVersion', 'Kind', 'Name', 'Status'],
            // colWidths: [100, 200]
            rows: rows
        });
        console.log(table.toString());
    }
    renderPackageManifestsErrors(manifestPackage) {
        var _a, _b;
        const manifestsWithErrors = the_lodash_1.default.chain(manifestPackage.manifests)
            .filter(x => !x.success)
            .orderBy([x => x.source.source.path, x => x.id.namespace, x => x.id.apiVersion, x => x.id.kind, x => x.id.name])
            .value();
        const rows = [];
        for (const x of manifestsWithErrors) {
            for (const error of x.errors) {
                rows.push([x.source.source.path, (_a = x.id.namespace) !== null && _a !== void 0 ? _a : '', x.id.apiVersion, x.id.kind, (_b = x.id.name) !== null && _b !== void 0 ? _b : '', error]);
            }
        }
        const table = new cli_table_1.default({
            head: ['File', 'Namespace', 'ApiVersion', 'Kind', 'Name', 'Error'],
            colWidths: [15, 15, 15, 15, 15, 70],
            rows: rows,
        });
        console.log(table.toString());
    }
}
exports.PackageRenderer = PackageRenderer;
//# sourceMappingURL=package-renderer.js.map