"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.readFromInputStream = void 0;
const the_promise_1 = require("the-promise");
const spinner_1 = require("../screen/spinner");
function readFromInputStream() {
    const stream = process.stdin;
    const spinner = (0, spinner_1.spinOperation)('Reading manifests from stdin...');
    let receivedSomething = false;
    const timer = setTimeout(() => {
        spinner.update('Reading manifests from stdin. Did you pipe something?');
    }, 5 * 1000);
    const terminateTimer = () => {
        clearTimeout(timer);
    };
    return the_promise_1.Promise.construct((resolve, reject) => {
        let data = '';
        stream.on('readable', () => {
            const chunk = stream.read();
            if (chunk !== null) {
                data += chunk;
                if (!receivedSomething) {
                    receivedSomething = true;
                    terminateTimer();
                }
            }
        });
        stream.on('end', () => {
            terminateTimer();
            spinner.complete('Received manifests from stdin.');
            resolve(data);
        });
        stream.on('error', (err) => {
            terminateTimer();
            spinner.fail(`Failed to read from stdin. ${err}`);
            reject(err);
        });
    });
}
exports.readFromInputStream = readFromInputStream;
//# sourceMappingURL=stream.js.map